==> kubernetes-model-1.0.52-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class PersistentVolumeClaimListBuilder extends PersistentVolumeClaimListFluentImpl<PersistentVolumeClaimListBuilder> implements VisitableBuilder<PersistentVolumeClaimList,PersistentVolumeClaimListBuilder>{

    PersistentVolumeClaimListFluent<?> fluent;
    Boolean validationEnabled;

    public PersistentVolumeClaimListBuilder(){
            this(true);
    }
    public PersistentVolumeClaimListBuilder(Boolean validationEnabled){
            this(new PersistentVolumeClaimList(), validationEnabled);
    }
    public PersistentVolumeClaimListBuilder(PersistentVolumeClaimListFluent<?> fluent){
            this(fluent, true);
    }
    public PersistentVolumeClaimListBuilder(PersistentVolumeClaimListFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new PersistentVolumeClaimList(), validationEnabled);
    }
    public PersistentVolumeClaimListBuilder(PersistentVolumeClaimListFluent<?> fluent,PersistentVolumeClaimList instance){
            this(fluent, instance, true);
    }
    public PersistentVolumeClaimListBuilder(PersistentVolumeClaimListFluent<?> fluent,PersistentVolumeClaimList instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withItems(instance.getItems()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            this.validationEnabled = validationEnabled; 
    }
    public PersistentVolumeClaimListBuilder(PersistentVolumeClaimList instance){
            this(instance,true);
    }
    public PersistentVolumeClaimListBuilder(PersistentVolumeClaimList instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.validationEnabled = validationEnabled; 
    }

    public PersistentVolumeClaimList build(){
            PersistentVolumeClaimList buildable = new PersistentVolumeClaimList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PersistentVolumeClaimListBuilder that = (PersistentVolumeClaimListBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.60-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class PersistentVolumeClaimListBuilder extends PersistentVolumeClaimListFluentImpl<PersistentVolumeClaimListBuilder> implements VisitableBuilder<PersistentVolumeClaimList,PersistentVolumeClaimListBuilder>{

    PersistentVolumeClaimListFluent<?> fluent;
    Boolean validationEnabled;

    public PersistentVolumeClaimListBuilder(){
            this(true);
    }
    public PersistentVolumeClaimListBuilder(Boolean validationEnabled){
            this(new PersistentVolumeClaimList(), validationEnabled);
    }
    public PersistentVolumeClaimListBuilder(PersistentVolumeClaimListFluent<?> fluent){
            this(fluent, true);
    }
    public PersistentVolumeClaimListBuilder(PersistentVolumeClaimListFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new PersistentVolumeClaimList(), validationEnabled);
    }
    public PersistentVolumeClaimListBuilder(PersistentVolumeClaimListFluent<?> fluent,PersistentVolumeClaimList instance){
            this(fluent, instance, true);
    }
    public PersistentVolumeClaimListBuilder(PersistentVolumeClaimListFluent<?> fluent,PersistentVolumeClaimList instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withItems(instance.getItems()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            this.validationEnabled = validationEnabled; 
    }
    public PersistentVolumeClaimListBuilder(PersistentVolumeClaimList instance){
            this(instance,true);
    }
    public PersistentVolumeClaimListBuilder(PersistentVolumeClaimList instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.validationEnabled = validationEnabled; 
    }

    public PersistentVolumeClaimList build(){
            PersistentVolumeClaimList buildable = new PersistentVolumeClaimList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PersistentVolumeClaimListBuilder that = (PersistentVolumeClaimListBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
